@@ -1,12 +1,6 @@
 #  MIXEDMODEL.R
 
-randomizedBlock <- function(formula, random, weights=NULL, only.varcomp=FALSE, data=list(), subset=NULL, contrasts=NULL, tol=1e-6, maxit=50, trace=FALSE)
-{
-	.Deprecated("mixedModel2")
-	mixedModel2(formula, random, weights, only.varcomp, data, subset, contrasts, tol, maxit, trace)
-}
-
-mixedModel2 <- function(formula, random, weights=NULL, only.varcomp=FALSE, data=list(), subset=NULL, contrasts=NULL, tol=1e-6, maxit=50, trace=FALSE)
+randomizedBlock <- mixedModel2 <- function(formula, random, weights=NULL, only.varcomp=FALSE, data=list(), subset=NULL, contrasts=NULL, tol=1e-6, maxit=50, trace=FALSE)
 #	REML for mixed linear models with 2 variance components
 #	Gordon Smyth, Walter and Eliza Hall Institute
 #	28 Jan 2003.  Last revised 20 October 2005.
@@ -41,13 +35,7 @@ mixedModel2 <- function(formula, random, weights=NULL, only.varcomp=FALSE, data=
 	mixedModel2Fit(y,x,z,w=w,only.varcomp=only.varcomp,tol=tol,maxit=maxit,trace=trace)
 }
 
-randomizedBlockFit <- function(y,X,Z,w=NULL,only.varcomp=FALSE,tol=1e-6,maxit=50,trace=FALSE)
-{
-	.Deprecated("mixedModel2Fit")
-	mixedModel2Fit(y,X,Z,w,only.varcomp,tol,maxit,trace)
-}
-
-mixedModel2Fit <- function(y,X,Z,w=NULL,only.varcomp=FALSE,tol=1e-6,maxit=50,trace=FALSE)
+randomizedBlockFit <- mixedModel2Fit <- function(y,X,Z,w=NULL,only.varcomp=FALSE,tol=1e-6,maxit=50,trace=FALSE)
 #	REML for mixed linear models with 2 variance components
 #	Fits the model  Y = X*BETA + Z*U + E  where BETA is fixed
 #	and U is random.
@@ -58,7 +46,7 @@ mixedModel2Fit <- function(y,X,Z,w=NULL,only.varcomp=FALSE,tol=1e-6,maxit=50,tra
 
 #	Gordon Smyth, Walter and Eliza Hall Institute
 #	Matlab version 19 Feb 94.  Converted to R, 28 Jan 2003.
-#	Last revised 20 Oct 2005
+#	Last revised 4 Jan 2020.
 {
 #  Prior weights
 if(!is.null(w)) {
@@ -104,7 +92,7 @@ if(mq > 2 && sum(abs(d)>1e-15)>1 && var(d)>1e-15) {
 	dfitted.values <- dfit$fitted.values
 }
 out <- list(varcomp=dfit$coef)
-out$reml.residuals <- uqy/sqrt(dfitted.values)
+#out$reml.residuals <- uqy/sqrt(dfitted.values)
 if(only.varcomp) return(out)
 
 #  Standard errors for variance components
@@ -117,7 +105,7 @@ d <- rep(0,mx)
 d[1:length(s$d)] <- s$d^2
 v <- drop( cbind(Residual=1,Block=d) %*% varcomp )
 mfit <- lm.wfit(x=crossprod(s$u,X),y=crossprod(s$u,y),w=1/v)
-out <- c(out,mfit)
+out$coefficients <- mfit$coefficients
 out$se.coefficients <- sqrt(diag(chol2inv(mfit$qr$qr)))
 
 out
